@@ -311,7 +311,7 @@ def fix_shared(paths, output_dir, pdf2png=False,dosvg=True,verbose=False, compil
 
         if rel not in target or target[rel]['hash'] != source[rel]['hash']:
             _ensure_target_dir_exists( output_dir + "/" + rel)
-            print(" -> ", output_dir + "/" + rel)
+            print("[fix shared] -> ", output_dir + "/" + rel)
             shutil.copy(shared_base +"/" + rel, output_dir + "/" + rel)
             target[rel] = source[rel].copy()
             target[rel]['modified'] = True
@@ -332,7 +332,7 @@ def fix_shared(paths, output_dir, pdf2png=False,dosvg=True,verbose=False, compil
     with open(output_dir + "/sharedcache.pkl", 'wb') as f:
         pickle.dump(target, f)
 
-    print("fix_shared()", time.time() - t0)
+    # print("fix_shared()", time.time() - t0)
 
     #
     # if pdf2png:
