@@ -9,7 +9,7 @@ def is_win():
     return platform.uname()[0].startswith("Windows")
 
 
-def is_compute():f
+def is_compute():
     return platform.uname()[1] == "linuxterm1"
 
 
